@@ -29,6 +29,14 @@ wk_handle <- function(handleable, handler, ...) {
   UseMethod("wk_handle")
 }
 
+#' @rdname wk_handle
+#' @export
+is_handleable <- function(handleable) {
+  force(handleable)
+  # use vector_meta because it doesn't ever iterate over an entire vector
+  tryCatch({wk_vector_meta(handleable); TRUE}, error = function(e) FALSE)
+}
+
 #' @rdname wk_handle
 #' @export
 new_wk_handler <- function(handler_ptr, subclass = character()) {
@@ -45,7 +53,13 @@ is_wk_handler <- function(handler) {
 #' @rdname wk_handle
 #' @export
 as_wk_handler <- function(handler, ...) {
-  if (is.function(handler)) handler() else handler
+  if (is.function(handler)) {
+    handler()
+  } else if (is_wk_handler(handler)) {
+    handler
+  } else {
+    stop("`handler` must be a wk handler object",  call. = FALSE)
+  }
 }
 
 #' @export
